[tor-commits] [bridgedb/master] Sphinxify bridgedb.test.test_https module docstring.

isis at torproject.org isis at torproject.org
Tue Feb 3 02:31:00 UTC 2015


commit 7ae1282581e3d690c310fa054a7d692f8cd2fe56
Author: Isis Lovecruft <isis at torproject.org>
Date:   Thu Aug 7 09:48:22 2014 +0000

    Sphinxify bridgedb.test.test_https module docstring.
---
 lib/bridgedb/test/test_https.py |   17 ++++++++++++++---
 1 file changed, 14 insertions(+), 3 deletions(-)

diff --git a/lib/bridgedb/test/test_https.py b/lib/bridgedb/test/test_https.py
index 8e0fc50..a154856 100644
--- a/lib/bridgedb/test/test_https.py
+++ b/lib/bridgedb/test/test_https.py
@@ -7,9 +7,19 @@
 #             (c) 2014, The Tor Project, Inc.
 # :license: see LICENSE for licensing information
 #_____________________________________________________________________________
-"""integration tests for BridgeDB .
-http://wwwsearch.sourceforge.net/mechanize/
-http://www.crummy.com/software/BeautifulSoup/bs3/documentation.html
+
+"""Integration tests for BridgeDB's HTTPS Distributor.
+
+These tests use `mechanize`_ and `BeautifulSoup`_, and require a BridgeDB
+instance to have been started in a separate process. To see how a BridgeDB is
+started for our CI infrastructure from a fresh clone of this repository, see
+the "before_script" section of the `.travis.yml` file in the top level of this
+repository.
+
+.. _mechanize: https://pypi.python.org/pypi/mechanize/
+    http://wwwsearch.sourceforge.net/mechanize/
+.. _BeautifulSoup:
+    http://www.crummy.com/software/BeautifulSoup/bs3/documentation.html
 """
 
 from __future__ import print_function
@@ -20,6 +30,7 @@ import mechanize
 HTTPS_ROOT = 'https://127.0.0.1:6789'
 CAPTCHA_RESPONSE = 'Tvx74Pmy'
 
+
 class HTTPTests(unittest.TestCase):
     def setUp(self):
 	self.br = None





More information about the tor-commits mailing list